@@ -5,27 +5,11 @@
 #define Py_TYPE(ob) (((PyObject*)(ob))->ob_type)
 #endif
 
-#if defined(_WIN32) && !defined(_WIN64)
-#define gmtime(t) _gmtime32(t)
-#define localtime(t) _localtime32(t)
-#define time_t __time32_t
-#endif
-
-#if defined(_WIN64) && !defined(_WIN32)
-#define gmtime(t) _gmtime64(t)
-#define localtime(t) _localtime64(t)
-#define time_t __time64_t
-#endif
-
 #ifdef MS_WINDOWS
 #define write(fd, buf, size) _write(fd, buf, size)
 #define read(fd, buf, size) _read(fd, buf, size)
 #define unlink(file) _unlink(file)
 #define open(file, flag, mode) _open(file, flag, mode)
-#define gmtime_r(t, tm) \
-    (gmtime(t)?memcpy((tm), gmtime(t), sizeof(*(tm))):NULL)
-#define localtime_r(t, tm) \
-    (localtime(t)?memcpy((tm), localtime(t), sizeof(*(tm))):NULL)
 #endif
 
 #define CUBRID_CLOB 'C'
@@ -273,230 +257,6 @@ _cubrid_connect (PyObject * self, PyObject * args, PyObject * kwargs)
 			kwargs);
 }
 
-static char _cubrid_Date__doc__[] = 
-"Date(year, month, day) --\n\
-This function constructs an object holding a date value.\n\
-\n\
-Parameters::\n\
-  year: int, supported range is 1-9999\n\
-  month: int, supported range is 1-12\n\
-  day: int, supported range is 1-31\n\
-\n\
-Return a date value string.\n\
-\n\
-Example::\n\
-  dt = _cubrid.Date(2011,6,1)\n\
-  cur.prepare(\"insert into test_cubrid(birthday) values (?)\")\n\
-  cur.bind_param(1, dt)\n\
-  cur.execute()";
-
-static PyObject *
-_cubrid_Date (PyObject * self, PyObject * args)
-{
-  int year, month, day;
-  char buf[16] = { '\0' };
-  if (!PyArg_ParseTuple (args, "iii", &year, &month, &day))
-    {
-      return NULL;
-    }
-  if (year <= 0 || year > 9999 || month <= 0 || month > 12 || day <= 0
-      || day > 31)
-    {
-      return handle_error (CUBRID_ER_INVALID_PARAM, NULL);
-    }
-  snprintf (buf, 16, "%d-%d-%d", year, month, day);
-
-  return _cubrid_return_PyString_FromString (buf);
-}
-
-static char _cubrid_Time__doc__[] = 
-"Time(hour, minute, second)\n\
-This function constructs an object holding a time value.\n\
-\n\
-Parameters::\n\
-  hour: int, supported range is 0-23\n\
-  minute: int, supported range is 0-59\n\
-  second: int, supported range is 0-59\n\
-\n\
-Return a time value string\n\
-\n\
-Example::\n\
-  tm = _cubrid.Time(11, 29, 59)\n\
-  cur.prepare('insert into test_cubrid(lunch) values (?)')\n\
-  cur.bind_param(1, tm)\n\
-  cur.execute()";
-
-static PyObject *
-_cubrid_Time (PyObject * self, PyObject * args)
-{
-  int hour, minute, second;
-  char buf[16] = { '\0' };
-  if (!PyArg_ParseTuple (args, "iii", &hour, &minute, &second))
-    {
-      return NULL;
-    }
-  if (hour < 0 || hour > 24 || minute < 0 || minute > 59 || second < 0
-      || second > 59)
-    {
-      return handle_error (CUBRID_ER_INVALID_PARAM, NULL);
-    }
-  snprintf (buf, 16, "%d:%d:%d", hour, minute, second);
-
-  return _cubrid_return_PyString_FromString (buf);
-}
-
-static char _cubrid_Timestamp__doc__[] =
-"Timestamp(year, month, day, hour, minute, second)\n\
-This function constructs an object holding a timestamp value.\n\
-\n\
-Parameters::\n\
-  year: int, supported range is 1-9999\n\
-  month: int, supported range is 1-12\n\
-  day: int, supported range is 1-31\n\
-  hour: int, supported range is 0-23\n\
-  minute: int, supported range is 0-59\n\
-  second: int, supported range is 0-59\n\
-\n\
-Return a timestamp value string.\n\
-\n\
-Example::\n\
-  ts = _cubrid.Timestamp(2011, 6, 1, 11, 29, 59)\n\
-  cur.prepare('insert into test_cubrid(lunch) values (?)')\n\
-  cur.bind_param(1, ts)\n\
-  cur.execute()";
-
-static PyObject *
-_cubrid_Timestamp (PyObject * self, PyObject * args)
-{
-  int year, month, day, hour, minute, second;
-  char buf[32] = { '\0' };
-
-  if (!PyArg_ParseTuple
-      (args, "iiiiii", &year, &month, &day, &hour, &minute, &second))
-    {
-      return NULL;
-    }
-
-  if (year <= 0 || year > 9999 || month <= 0 || month > 12 || day <= 0
-      || day > 31 || hour < 0 || hour > 24 || minute < 0 || minute > 59
-      || second < 0 || second > 59)
-    {
-      return handle_error (CUBRID_ER_INVALID_PARAM, NULL);
-    }
-
-  snprintf (buf, 32, "%d-%d-%d %d:%d:%d", year, month, day, hour, minute,
-	    second);
-
-  return _cubrid_return_PyString_FromString (buf);
-}
-
-static char _cubrid_DateFromTicks__doc__[] = 
-"DateFromTicks(ticks)\n\
-This function constructs an object holding a date value from the\n\
-given ticks value (number of seconds since the epoch; see the\n\
-documentation of the standard Python time module for details).\n\
-\n\
-ticks: double\n\
-\n\
-Return a date value string.";
-
-static PyObject *
-_cubrid_DateFromTicks (PyObject * self, PyObject * args)
-{
-  double ticks;
-  struct tm tm;
-  time_t t;
-  PyObject *result = NULL;
-  if (!PyArg_ParseTuple (args, "d", &ticks))
-    {
-      return NULL;
-    }
-  t = (time_t) floor (ticks);
-  if (localtime_r (&t, &tm))
-    {
-      args =
-	Py_BuildValue ("iii", tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday);
-      if (args)
-	{
-	  result = _cubrid_Date (self, args);
-	  Py_DECREF (args);
-	}
-    }
-  return result;
-}
-
-static char _cubrid_TimeFromTicks__doc__[] = 
-"TimeFromTicks(ticks)\n\
-This function constructs an object holding a time value from the\n\
-given ticks value (number of seconds since the epoch; see the\n\
-documentation of the standard Python time module for details).\n\
-\n\
-ticks: double\n\
-\n\
-Return a time value string.";
-
-static PyObject *
-_cubrid_TimeFromTicks (PyObject * self, PyObject * args)
-{
-  double ticks;
-  struct tm tm;
-  time_t t;
-  PyObject *result = NULL;
-  if (!PyArg_ParseTuple (args, "d", &ticks))
-    {
-      return NULL;
-    }
-  t = (time_t) floor (ticks);
-  ticks -= (double) t;
-  if (localtime_r (&t, &tm))
-    {
-      args = Py_BuildValue ("iii", tm.tm_hour, tm.tm_min, tm.tm_sec);
-      if (args)
-	{
-	  result = _cubrid_Time (self, args);
-	  Py_DECREF (args);
-	}
-    }
-  return result;
-}
-
-static char _cubrid_TimestampFromTicks__doc__[] =
-"TimestampFromTicks(ticks)\n\
-This function constructs an object holding a time stamp value from\n\
-the given ticks value (number of seconds since the epoch; see the\n\
-documentation of the standard Python time module for details).\n\
-\n\
-ticks: double\n\
-\n\
-Return a timestamp value string.";
-
-static PyObject *
-_cubrid_TimestampFromTicks (PyObject * self, PyObject * args)
-{
-  double ticks;
-  struct tm tm;
-  time_t t;
-  PyObject *result = NULL;
-  if (!PyArg_ParseTuple (args, "d", &ticks))
-    {
-      return NULL;
-    }
-  t = (time_t) floor (ticks);
-  ticks -= (double) t;
-  if (localtime_r (&t, &tm))
-    {
-      args =
-	Py_BuildValue ("iiiiii", tm.tm_year + 1900, tm.tm_mon + 1,
-		       tm.tm_mday, tm.tm_hour, tm.tm_min, tm.tm_sec);
-      if (args)
-	{
-	  result = _cubrid_Timestamp (self, args);
-	  Py_DECREF (args);
-	}
-    }
-  return result;
-}
-
 static PyObject *
 _cubrid_ConnectionObject_new (PyTypeObject * type, PyObject * args,
 			      PyObject * kwargs)
@@ -1984,6 +1744,7 @@ _cubrid_CursorObject_dbval_to_pyvalue (_cubrid_CursorObject * self, int type,
 #endif
 	  Py_DECREF (tmpval);
 	}
+      break;
     default:
       res = cci_get_data (self->handle, index, CCI_A_TYPE_STR, &buffer, &ind);
       if (res < 0)
@@ -3276,36 +3037,6 @@ static struct PyMethodDef _cubrid_methods[] = {
    (PyCFunction) _cubrid_connect,
    METH_VARARGS | METH_KEYWORDS,
    _cubrid_connect__doc__},
-  {
-   "Date",
-   (PyCFunction) _cubrid_Date,
-   METH_VARARGS,
-   _cubrid_Date__doc__},
-  {
-   "Time",
-   (PyCFunction) _cubrid_Time,
-   METH_VARARGS,
-   _cubrid_Time__doc__},
-  {
-   "Timestamp",
-   (PyCFunction) _cubrid_Timestamp,
-   METH_VARARGS,
-   _cubrid_Timestamp__doc__},
-  {
-   "DateFromTicks",
-   (PyCFunction) _cubrid_DateFromTicks,
-   METH_VARARGS,
-   _cubrid_DateFromTicks__doc__},
-  {
-   "TimeFromTicks",
-   (PyCFunction) _cubrid_TimeFromTicks,
-   METH_VARARGS,
-   _cubrid_TimeFromTicks__doc__},
-  {
-   "TimestampFromTicks",
-   (PyCFunction) _cubrid_TimestampFromTicks,
-   METH_VARARGS,
-   _cubrid_TimestampFromTicks__doc__},
   {NULL, NULL}
 };
 
@@ -3401,7 +3132,7 @@ PyTypeObject _cubrid_CursorObject_type = {
   0,				/* tp_free */
 };
 
-#define _CUBRID_VERSION_	"8.4.0.1.0.0"
+#define _CUBRID_VERSION_	"8.4.1.0001"
 static char _cubrid_doc[] = "CUBRID API Module for Python";
 
 #if PY_MAJOR_VERSION >= 3
