@@ -10,8 +10,8 @@ class DBAPI20Test(unittest.TestCase):
 
     ddl1 = 'create table %sbooze (name varchar(20))' % table_prefix
     ddl2 = 'create table %sbarflys (name varchar(20))' % table_prefix
-    xddl1 = 'drop table %sbooze' % table_prefix
-    xddl2 = 'drop table %sbarflys' % table_prefix
+    xddl1 = 'drop table if exists %sbooze' % table_prefix
+    xddl2 = 'drop table if exists %sbarflys' % table_prefix
 
     def executeDDL1(self, cursor):
         cursor.execute(self.ddl1)
@@ -25,11 +25,20 @@ class DBAPI20Test(unittest.TestCase):
     def tearDown(self):
         pass
 
+    def _check_table_exist(self, connect):
+        cursor = connect.cursor()
+        cursor.execute(self.xddl1)
+        cursor.execute(self.xddl2)
+        connect.commit()
+        cursor.close()
+
     def _connect(self):
         try:
-            return self.driver.connect(
+            con = self.driver.connect(
                     *self.connect_args, **self.connect_kw_args
                     )
+            self._check_table_exist(con)
+            return con
         except AttributeError:
             self.fail("No connect method found in self.driver module")
 
